@@ -8,7 +8,7 @@ import json
 import fnmatch
 from pathlib import Path
 import requests
-from pyutilb import log, ocr_youdao
+from pyutilb import log, YamlBoot, BreakException, ocr_youdao
 from pyutilb.util import *
 import base64
 from MiniumBoot.validator import Validator
@@ -20,6 +20,7 @@ from minium.framework.assertbase import AssertBase
 from at.core.adbwrap import AdbWrap
 from minium.native.wx_native.androidnative import WXAndroidNative
 from MiniumBoot.driver import MiniTestDriver
+from minium.framework.exception import MiniElementNotFoundError
 
 # 扩展BaseElement方法
 def get_value_or_text(self):
@@ -29,45 +30,22 @@ def get_value_or_text(self):
     return self.inner_text
 minium.BaseElement.get_value_or_text = get_value_or_text
 
-# 跳出循环的异常
-class BreakException(Exception):
-    def __init__(self, condition):
-        self.condition = condition # 跳转条件
-
 # Minium基于yaml的启动器
-class Boot(object):
+class Boot(YamlBoot):
 
     def __init__(self):
         super().__init__()
-        # 延迟初始化driver
-        self.driver = None
-        # 当前页面的校验器, 依赖于driver
-        self.validator = None
-        # 当前页面的提取器, 依赖于driver
-        self.extractor = None
-        # 加载的 TestSuite
-        self.suite = None
-        # 项目代码中的app.json数据
-        self.appjson = None
-        # 延迟初始化的app包
-        self.package = None
-        # 步骤文件所在的目录
-        self.step_dir = None
-        # 已下载过的url对应的文件，key是url，value是文件
-        self.downloaded_files = {}
-        # 基础url
-        self._base_url = None
         # 动作映射函数
-        self.actions = {
+        actions = {
             'init_driver': self.init_driver,
             'close_driver': self.close_driver,
-            'sleep': self.sleep,
-            'print': self.print,
             'input_by_id': self.input_by_id,
             'input_by_css': self.input_by_css,
             'input_by_xpath': self.input_by_xpath,
             'hide_keyboard': self.hide_keyboard,
             'page_scroll': self.page_scroll,
+            'page_scroll_top': self.page_scroll_top,
+            'page_scroll_bottom': self.page_scroll_bottom,
             'scroll_by': self.scroll_by,
             'scroll_up_by': self.scroll_up_by,
             'scroll_down_by': self.scroll_down_by,
@@ -87,6 +65,7 @@ class Boot(object):
             'screenshot': self.screenshot,
             'execute_js': self.execute_js,
             'call_wx_method': self.call_wx_method,
+            'call_page_method': self.call_page_method,
             'goto': self.goto,
             'switch_tab': self.switch_tab,
             'back': self.back,
@@ -101,15 +80,9 @@ class Boot(object):
             'print_system_info': self.print_system_info,
             'print_all_pages': self.print_all_pages,
             'print_current_page': self.print_current_page,
-            'for': self.do_for,
-            'once': self.once,
-            'break_if': self.break_if,
-            'moveon_if': self.moveon_if,
             'moveon_if_exist_by': self.moveon_if_exist_by,
+            'break_if_exist_by': self.break_if_exist_by,
             'break_if_not_exist_by': self.break_if_not_exist_by,
-            'include': self.include,
-            'set_vars': self.set_vars,
-            'print_vars': self.print_vars,
             'base_url': self.base_url,
             'get': self.get,
             'post': self.post,
@@ -124,7 +97,6 @@ class Boot(object):
             'extract_by_xpath': self.extract_by_xpath,
             'extract_by_id': self.extract_by_id,
             'extract_by_eval': self.extract_by_eval,
-            'exec': self.exec,
 
             # 以下步骤是根据官方api封装, 但发现api无用
             'swipe': self.swipe,
@@ -140,84 +112,74 @@ class Boot(object):
             'zoom_in_by': self.zoom_in_by,
             'zoom_out_by': self.zoom_out_by,
         }
-        set_var('boot', self)
-        # 当前文件
-        self.step_file = None
+        self.add_actions(actions)
+
+        # 延迟初始化driver
+        self.driver = None
+        # 当前页面的校验器, 依赖于driver
+        self.validator = None
+        # 当前页面的提取器, 依赖于driver
+        self.extractor = None
+        # 加载的 TestSuite
+        self.suite = None
+        # 项目代码中的app.json数据
+        self.appjson = None
+        # 延迟初始化的app包
+        self.package = None
+        # 已下载过的url对应的文件，key是url，value是文件
+        self.downloaded_files = {}
+        # 基础url
+        self._base_url = None
         # 视频/音频文件
         self.video_ele = None
 
-    '''
-    执行入口
-    :param step_files 步骤配置文件或目录的列表
-    '''
-    def run(self, step_files):
-        for path in step_files:
-            # 1 模式文件
-            if '*' in path:
-                dir, pattern = path.rsplit(os.sep, 1)  # 从后面分割，分割为目录+模式
-                if not os.path.exists(dir):
-                    raise Exception(f'步骤配置目录不存在: {dir}')
-                self.run_1dir(dir, pattern)
-                return
-
-            # 2 不存在
-            if not os.path.exists(path):
-                raise Exception(f'步骤配置文件或目录不存在: {path}')
-
-            # 3 目录: 遍历执行子文件
-            if os.path.isdir(path):
-                self.run_1dir(path)
-                return
-
-            # 4 纯文件
-            self.run_1file(path)
-
-    # 执行单个步骤目录: 遍历执行子文件
-    # :param path 目录
-    # :param pattern 文件名模式
-    def run_1dir(self, dir, pattern ='*.yml'):
-        # 遍历目录: https://blog.csdn.net/allway2/article/details/124176562
-        files = os.listdir(dir)
-        files.sort() # 按文件名排序
-        for file in files:
-            if fnmatch.fnmatch(file, pattern): # 匹配文件名模式
-                file = os.path.join(dir, file)
-                if os.path.isfile(file):
-                    self.run_1file(file)
 
     # 执行单个步骤文件
     # :param step_file 步骤配置文件路径
     # :param include 是否inlude动作触发
-    def run_1file(self, step_file, include = False):
-        # 获得步骤文件的绝对路径
-        if include: # 补上绝对路径
-            if not os.path.isabs(step_file):
-                step_file = self.step_dir + os.sep + step_file
-        else: # 记录目录
-            step_file = os.path.abspath(step_file)
-            self.step_dir = os.path.dirname(step_file)
-
-        log.debug(f"加载并执行步骤文件: {step_file}")
-        # 获得步骤
-        steps = read_yaml(step_file)
-        if self.step_file == None and self.driver == None: # 首次执行: 初始化driver + 再运行单元测试
+    def run_1file(self, step_file, include=False):
+        # 首次执行
+        is_first = self.step_file == None and self.driver == None
+        # 加载步骤文件：会更新 self.step_dir 与 self.step_file
+        steps = self.load_1file(step_file, include)
+        log.debug(f"Load and run step file: {self.step_file}")
+        # 执行步骤
+        if is_first:  # 首次执行: 初始化driver + 再运行单元测试
             self.init_and_run_test(steps)
-        else: # 执行多个步骤
+        else:  # 执行多个步骤
             self.step_file = step_file
             self.run_steps(steps)
 
+    # 获得 init_driver 动作参数
+    def get_init_driver_step(self, steps):
+        err = '未找到第一个动作: init_driver'
+        if len(steps) == 0:
+            raise Exception(err)
+        if 'init_driver' in steps[0]:
+            return steps[0]['init_driver']
+
+        # 递归获得include中的 init_driver 动作
+        if 'include' in steps[0]:
+            # 加载步骤文件
+            step_file = steps[0]['include']
+            step_file, steps = self.load_1file(step_file, True)
+            # 递归获得 init_driver 动作
+            return self.get_init_driver_step(steps)
+
+        raise Exception(err)
+
     # 首次执行: 先初始化driver, 再运行单元测试
     def init_and_run_test(self, steps):
-        if len(steps) == 0 or 'init_driver' not in steps[0]:
-            raise Exception('未找到第一个动作: init_driver')
         # 1 初始化driver
-        params = steps[0]['init_driver']
+        params = self.get_init_driver_step(steps)
         self.init_driver(params)
 
         # 修改 MiniTestDriver.test_boot
         boot = self
+
         def test_boot(driver):
             boot.run_steps(steps)
+
         MiniTestDriver.test_boot = test_boot
 
         # 运行测试用例 tests 用例对象, 为 TestSuits: MiniTestDriver.test_boot
@@ -226,34 +188,7 @@ class Boot(object):
 
         # 输出结果
         result.print_shot_msg()
-        result.dumps(AssertBase.CONFIG.outputs) # 用例运行的结果存放目录
-
-
-    # 执行多个步骤
-    def run_steps(self, steps):
-        # 逐个步骤调用多个动作
-        for step in steps:
-            for action, param in step.items():
-                self.run_action(action, param)
-
-    '''
-    执行单个动作：就是调用动作名对应的函数
-    :param action 动作名
-    :param param 参数
-    '''
-    def run_action(self, action, param):
-        if 'for(' in action:
-            n = int(action[4:-1])
-            self.do_for(param, n)
-            return
-
-        if action not in self.actions:
-            raise Exception(f'无效动作: [{action}]')
-
-        # 调用动作对应的函数
-        log.debug(f"处理动作: {action}={param}")
-        func = self.actions[action]
-        func(param)
+        result.dumps(AssertBase.CONFIG.outputs)  # 用例运行的结果存放目录
 
     # --------- 动作处理的函数 --------
     # 初始化driver
@@ -299,6 +234,8 @@ class Boot(object):
             }
         }
         '''
+        # 替换配置中的变量
+        config = replace_var(config, False)
         # app.json
         path = config['project_path'] + os.sep + 'miniprogram' + os.sep + 'app.json'
         self.appjson = read_json(path)
@@ -348,41 +285,6 @@ class Boot(object):
     def mini(self):
         return self.driver.mini
 
-    # for循环
-    # :param steps 每个迭代中要执行的步骤
-    # :param n 循环次数
-    def do_for(self, steps, n = None):
-        label = f"for({n})"
-        if n == None:
-            n = sys.maxsize # 最大int，等于无限循环次数
-            label = f"for(∞)"
-        log.debug(f"-- 开始循环: {label} -- ")
-        try:
-            for i in range(n):
-                # i+1表示迭代次数比较容易理解
-                log.debug(f"第{i+1}次迭代")
-                set_var('for_i', i+1)
-                self.run_steps(steps)
-        except BreakException as e:  # 跳出循环
-            log.debug(f"-- 跳出循环: {label}, 跳出条件: {e.condition} -- ")
-        else:
-            log.debug(f"-- 终点循环: {label} -- ")
-
-    # 执行一次子步骤，相当于 for(1)
-    def once(self, steps):
-        self.do_for(steps, 1)
-
-    # 检查并继续for循环
-    def moveon_if(self, expr):
-        # break_if(条件取反)
-        self.break_if(f"not ({expr})")
-
-    # 跳出for循环
-    def break_if(self, expr):
-        val = eval(expr, globals(), bvars)  # 丢失本地与全局变量, 如引用不了json模块
-        if bool(val):
-            raise BreakException(expr)
-
     # 检查并继续for循环
     def moveon_if_exist_by(self, config):
         self.break_if_not_exist_by(config)
@@ -392,29 +294,10 @@ class Boot(object):
         if not self.exist_by_any(config):
             raise BreakException(config)
 
-    # 加载并执行其他步骤文件
-    def include(self, step_file):
-        self.run_1file(step_file, True)
-
-    # 设置变量
-    def set_vars(self, vars):
-        for k, v in vars.items():
-            v = replace_var(v)  # 替换变量
-            set_var(k, v)
-
-    # 打印变量
-    def print_vars(self, _):
-        log.info(f"打印变量: {bvars}")
-
-    # 睡眠
-    def sleep(self, seconds):
-        seconds = replace_var(seconds)  # 替换变量
-        time.sleep(int(seconds))
-
-    # 打印
-    def print(self, msg):
-        msg = replace_var(msg)  # 替换变量
-        log.info(msg)
+    # 跳出for循环
+    def break_if_exist_by(self, config):
+        if self.exist_by_any(config):
+            raise BreakException(config)
 
     # 解析响应
     def _analyze_response(self, res, config):
@@ -447,14 +330,13 @@ class Boot(object):
     # :param input_data 表单数据, key是输入框的路径, value是填入的值
     def _input_by_type_and_data(self, type, input_data):
         for name, value in input_data.items():
-            log.debug(f"替换变量： {name} = {value}")
             value = replace_var(value)  # 替换变量
 
             # 找到输入框
             try:
                 ele = self.find_by(type, name)
             except Exception as ex:  # 找不到元素
-                log.error(f"找不到输入元素{name}", exc_info = ex)
+                log.error(f"Input element not found{name}", exc_info=ex)
                 continue
 
             # 输入
@@ -465,9 +347,9 @@ class Boot(object):
             elif ele._tag_name == 'picker':
                 ele.click()  # 阻止picker弹起
                 ele.pick(value)  # 用trigger模拟pick完成的动作
-            else:#elif ele._tag_name == 'input':
+            else:  # elif ele._tag_name == 'input':
                 # ele.trigger("input", {"value": value})  # 直接触发事件，但是不会影响UI变化
-                ele.input(str(value)) # UI有变化
+                ele.input(str(value))  # UI有变化
 
     # 隐藏键盘
     def hide_keyboard(self, _):
@@ -483,15 +365,26 @@ class Boot(object):
         for type in types:
             if type in config:
                 path = config[type]
-                if type == 'xpath': # xpath支持变量
+                if type == 'xpath':  # xpath支持变量
                     path = replace_var(path)
                 return self.find_by(type, path)
-        raise Exception(f"没有查找类型: {config}")
+        raise Exception(f"Invalid find type: {config}")
+
+    # 根据指定类型，检查元素是否存在
+    def exist_by(self, type, path):
+        try:
+            self.find_by(type, path)
+            return True
+        except MiniElementNotFoundError:
+            return False
 
     # 根据任一类型，检查元素是否存在
     def exist_by_any(self, config):
-        selector = config
-        return self.page.element_is_exists(selector, max_timeout=5)
+        try:
+            self.find_by_any(config)
+            return True
+        except MiniElementNotFoundError:
+            return False
 
     def calculate_new_scroll_pos(self, xy, wh, old_xy):
         '''
@@ -540,14 +433,27 @@ class Boot(object):
         y = self.calculate_new_scroll_pos(y, page.inner_size["height"], page.scroll_y)
         page.scroll_to(y)
 
-    # 滚动元素(传元素+坐标)
+    # 滚动到页面顶部
+    def page_scroll_top(self, y):
+        self.page.scroll_to(0)
+
+    # 滚动到页面底部
+    def page_scroll_bottom(self, y):
+        page = self.page
+        page.scroll_to(page.scroll_height)
+
+    # 滚动元素(传元素+坐标) -- 基础库v2.23.4版本后支持
     # :param config {id, css, path, pos}
     def scroll_by(self, config):
         ele = self.find_by_any(config)
         x, y = config['pos'].split(",", 1)
         # 计算新的滚动位置
-        x = self.calculate_new_scroll_pos(x, ele.size['width'], ele.scroll_left)
-        y = self.calculate_new_scroll_pos(y, ele.size['height'], ele.scroll_top)
+        left = top = 0
+        if hasattr(ele, 'scroll_left'):
+            left = ele.scroll_left
+            top = ele.scroll_top
+        x = self.calculate_new_scroll_pos(x, ele.size['width'], left)
+        y = self.calculate_new_scroll_pos(y, ele.size['height'], top)
         ele.scroll_to(x, y)
 
     # 向上滚动元素
@@ -648,14 +554,14 @@ class Boot(object):
             'get_we_run_data',
         ]
         if perm not in perms:
-            raise Exception(f"无效权限: {perm}")
+            raise Exception(f"Invalid perm: {perm}")
         # 获得对应方法，如 login 权限对应授权方法为 self.native.allow_login()
         method = f"allow_{perm}"
         self.native[method]
 
     # 点击弹窗的按钮
     # :param btn_text 按钮文本或bool
-    def handle_modal(self, btn_text = "确定"):
+    def handle_modal(self, btn_text="确定"):
         if isinstance(btn_text, bool):
             if btn_text:
                 btn_text = '确定'
@@ -705,14 +611,25 @@ class Boot(object):
         args = []
         ret = self.app.evaluate(js, args, sync=True)
         ret = ret.get("result", {}).get("result")
+        set_var('return_val', ret)
+
+    # 调用页面方法，如getTabBar
+    def call_page_method(self, method, args=None):
+        if args == None and isinstance(method, list):
+            args = method[1:]
+            method = method[0]
+        ret = self.page.call_method(method, args)
+        ret = ret.get("result", {}).get("result")
+        set_var('return_val', ret)
 
     # 调用微信函数
-    def call_wx_method(self, method, args = None):
+    def call_wx_method(self, method, args=None):
         if args == None and isinstance(method, list):
             args = method[1:]
             method = method[0]
         ret = self.app.call_wx_method(method, args)
-        return ret.get("result", {}).get("result")
+        ret = ret.get("result", {}).get("result")
+        set_var('return_val', ret)
 
     # 跳转到指定页面, 但是不能跳到 tabbar 页面
     def goto(self, url):
@@ -726,7 +643,7 @@ class Boot(object):
             i = url_or_index
             tabs = self.appjson['tabBar']['list']
             if len(tabs) <= i:
-                raise Exception(f'索引是{i}, 超过 tabBar 页面数')
+                raise Exception(f'Invalid tabbar index {i}, exceeds of tabbar page number')
             url = '/' + tabs[i]['pagePath']
         else:
             url = url_or_index
@@ -787,16 +704,16 @@ class Boot(object):
         self.call_wx_method("sendSms", [{"phoneNumber": phone, "content": content}])
 
     # 打印系统信息
-    def print_system_info(self, _):
+    def print_system_info(self, _ = None):
         info = self.mini.get_system_info()
         log.debug('system_info: ' + json.dumps(info))
 
     # 打印所有页面
-    def print_all_pages(self, _):
+    def print_all_pages(self, _ = None):
         log.debug('all pages: ' + ', '.join(self.app.get_all_pages_path()))
 
     # 打印当前页面
-    def print_current_page(self, _):
+    def print_current_page(self, _ = None):
         # page = self.app.get_current_page()
         page = self.page
         log.debug('current_page: ' + str(page) + ', data: ' + json.dumps(page.data))
@@ -817,7 +734,7 @@ class Boot(object):
 
     # get请求
     # :param config {url, is_ajax, data, validate_by_jsonpath, validate_by_css, validate_by_xpath, extract_by_jsonpath, extract_by_css, extract_by_xpath, extract_by_eval}
-    def get(self, config = {}):
+    def get(self, config={}):
         url = self._get_url(config)
         data = replace_var(config['data'], False)
         headers = {}
@@ -832,7 +749,7 @@ class Boot(object):
 
     # post请求
     # :param config {url, is_ajax, data, validate_by_jsonpath, validate_by_css, validate_by_xpath, extract_by_jsonpath, extract_by_css, extract_by_xpath, extract_by_eval}
-    def post(self, config = {}):
+    def post(self, config={}):
         url = self._get_url(config)
         data = replace_var(config['data'], False)
         headers = {}
@@ -846,7 +763,7 @@ class Boot(object):
 
     # 上传文件
     # :param config {url, files, validate_by_jsonpath, validate_by_css, validate_by_xpath, extract_by_jsonpath, extract_by_css, extract_by_xpath, extract_by_eval}
-    def upload(self, config = {}):
+    def upload(self, config={}):
         url = self._get_url(config)
         # 文件
         files = {}
@@ -890,13 +807,13 @@ class Boot(object):
         if os.path.exists(save_file):
             for i in range(100000000000000):
                 if '.' in save_file:
-                    path, ext = save_file.rsplit(".", 1) # 从后面分割，分割为路径+扩展名
+                    path, ext = save_file.rsplit(".", 1)  # 从后面分割，分割为路径+扩展名
                     newname = f"{path}-{i}.{ext}"
                 else:
                     newname = f"{save_file}-{i}"
                 if not os.path.exists(newname):
                     return newname
-            raise Exception('目录太多文件，建议新建目录')
+            raise Exception('Too many file in save_dir, please change other directory.')
 
         return save_file
 
@@ -912,7 +829,7 @@ class Boot(object):
         # 设置变量
         set_var('download_file', save_file)
         self.downloaded_files[url] = save_file
-        log.debug(f"下载文件: url为{url}, 另存为{save_file}")
+        log.debug(f"Dowload file: url is {url}, save path is{save_file}")
         return save_file
 
     # 播放视频/音频
@@ -975,8 +892,8 @@ class Boot(object):
     # 屏幕横扫(传坐标)
     # :param config {from, to, duration}
     def swipe(self, config):
-        x1, y1 = config['from'].split(",", 1) # 起点位置
-        x2, y2 = config['to'].split(",", 1) # 终点位置
+        x1, y1 = config['from'].split(",", 1)  # 起点位置
+        x2, y2 = config['to'].split(",", 1)  # 终点位置
         duration = 0
         if 'duration' in config:
             duration = float(config['duration'])
@@ -992,11 +909,11 @@ class Boot(object):
         ele.touch_start(touches=[touch1], changed_touches=[touch1])
 
         # 两个手指移动到结尾
-        time.sleep(duration/2)
+        time.sleep(duration / 2)
         touch2 = self.build_touch(x2, y2, ele)
         ele.touch_move(touches=[touch2], changed_touches=[touch2])
 
-        time.sleep(duration/2)
+        time.sleep(duration / 2)
         ele.touch_end(changed_touches=[touch2])
 
     # 上滑(传比例)
@@ -1021,18 +938,18 @@ class Boot(object):
 
     # 左滑(传y坐标)
     # :param y y坐标，固定不变，默认为中间
-    def swipe_left(self, y = None):
+    def swipe_left(self, y=None):
         self.swipe_horizontal('0.75,0.25', y)
 
     # 右滑(传y坐标)
     # :param y y坐标，固定不变，默认为中间
-    def swipe_right(self, y = None):
+    def swipe_right(self, y=None):
         self.swipe_horizontal('0.25,0.75', y)
 
     # 垂直方向(上下)滑动
     # :param y_range_ratios y轴起点/终点位置在屏幕的比例，如 0.2,0.7，即y轴上从屏幕0.2比例处滑到0.7比例处
     # :param xm x坐标，固定不变，默认为中间
-    def swipe_vertical(self, y_range_ratios, xm = None):
+    def swipe_vertical(self, y_range_ratios, xm=None):
         # 获取屏幕的宽高
         size = self.page.inner_size
         w = size["width"]
@@ -1041,7 +958,7 @@ class Boot(object):
         if xm == None:
             xm = int(w * 0.5)
         # y:按比例计算坐标
-        y1_ratio, y2_ratio = y_range_ratios.split(",", 1) # y轴起点/终点位置在屏幕的比例
+        y1_ratio, y2_ratio = y_range_ratios.split(",", 1)  # y轴起点/终点位置在屏幕的比例
         y1 = int(h * float(y1_ratio))
         y2 = int(h * float(y2_ratio))
         duration = 0.1
@@ -1050,7 +967,7 @@ class Boot(object):
     # 水平方向(左右)滑动
     # :param x_range_ratios x轴起点/终点位置在屏幕的比例，如 0.2,0.7，即x轴上从屏幕0.2比例处滑到0.7比例处
     # :param ym y坐标，固定不变，默认为中间
-    def swipe_horizontal(self, x_range_ratios, ym = None):
+    def swipe_horizontal(self, x_range_ratios, ym=None):
         # 获取屏幕的宽高
         size = self.page.inner_size
         w = size["width"]
@@ -1142,28 +1059,25 @@ class Boot(object):
 
     # 获得缩放时2个手指的y轴起点/终点位置在屏幕的比例，分别是: 两个手指的起点y比例, 两个手指的终点y比例
     def get_zoom_y_range_ratios(self, is_up):
-        if is_up: # 放大：从中间到两边
+        if is_up:  # 放大：从中间到两边
             return 0.5, 0.5, 9.9, 0.1
 
         # 缩小: 从两边到中间
         return 9.9, 0.1, 0.5, 0.5
 
-    # 执行命令
-    def exec(self, cmd):
-        output = os.popen(cmd).read()
-        log.debug(f"执行命令: {cmd} | 结果: {output}")
-
 
 # cli入口
 def main():
     # 基于yaml的执行器
     boot = Boot()
+    # 读元数据：author/version/description
+    dir = os.path.dirname(__file__)
+    meta = read_init_file_meta(dir + os.sep + '__init__.py')
+    # 步骤配置的yaml
+    step_files = parse_cmd('MiniumBoot', meta['version'])
+    if len(step_files) == 0:
+        raise Exception("Miss step config file or directory")
     try:
-        # 步骤配置的yaml
-        if len(sys.argv) > 1:
-            step_files = sys.argv[1:]
-        else:
-            raise Exception("未指定步骤配置文件或目录")
         # 执行yaml配置的步骤
         boot.run(step_files)
     except Exception as ex:
@@ -1174,12 +1088,13 @@ def main():
             src = boot.driver.page_source
             # report_to_sauce(boot.driver.session_id)
             # take_screenshot_and_logcat(boot.driver, device_logger, calling_request)
-        # log.error(f"异常环境:当前步骤文件为 {step_file}, 当前page为 {page}, 当前层级为 {src}", exc_info = ex)
-        log.error(f"异常环境:当前步骤文件为 {boot.step_file}, 当前page为 {page}", exc_info = ex)
+        # log.error(f"Exception occurs: current step file is {step_file}, 当前page为 {page}, current page source is {src}", exc_info = ex)
+        log.error(f"Exception occurs: current step file is {boot.step_file}, 当前page为 {page}", exc_info=ex)
         raise ex
     finally:
         boot
-        #boot.close_driver()
+        # boot.close_driver()
+
 
 if __name__ == '__main__':
-    main()
\ No newline at end of file
+    main()
