@@ -2,6 +2,7 @@
 # -*- coding: utf-8 -*-
 
 import re
+from pyutilb.util import *
 from lxml import etree
 from requests import Response
 from jsonpath import jsonpath
@@ -19,42 +20,43 @@ class ResponseWrap(object):
     # 获得元素值
     def _get_val_by(self, type, path):
         if type == 'css':
+            path, prop = split_css_and_prop(path)
             if self.res != None:
                 html = etree.fromstring(self.res.text, etree.HTMLParser())
-                return html.cssselect(path)[0].text
-
-            return self.driver.find_element_by('css', path).get_value_or_text()
+                ele = html.cssselect(path)[0]
+            else:
+                ele = self.driver.find_element_by('css', path)
+            return self.get_prop_or_text(ele, prop)
 
         if type == 'xpath':
-            # 检查xpath是否最后有属性
-            mat = re.search('/@[\w\d_]+$', path)
-            prop = ''
-            if (mat != None):  # 有属性
-                # 分离元素path+属性
-                prop = mat.group()
-                path = path.replace(prop, '')
-                prop = prop.replace('/@', '')
-
+            path, prop = split_xpath_and_prop(path)
             if self.res != None:
                 html = etree.fromstring(self.res.text, etree.HTMLParser())
                 ele = html.xpath(path)[0]
-                if prop != '': # 获得属性
-                    return ele.get(prop)
-                return ele.text
-
-            ele = self.driver.find_element_by('xpath', path)
-            if prop != '': # 获得属性
-                return ele.attribute(prop)
-            return ele.get_value_or_text()
+            else:
+                ele = self.driver.find_element_by('xpath', path)
+            return self.get_prop_or_text(ele, prop)
 
         if type == 'jsonpath':
             if self.res != None:
                 data = self.res.json()
                 return jsonpath(data, path)[0]
 
-            raise Exception(f"无http响应, 不支持查找类型: {type}")
+            raise Exception(f"No http response => invalid find type: {type}")
 
         if type == 'id':
             return self.driver.find_element_by('id', path).get_value_or_text()
 
-        raise Exception(f"不支持查找类型: {type}")
\ No newline at end of file
+        raise Exception(f"Invalid find type: {type}")
+
+    # 获得元素的属性值或文本
+    def get_prop_or_text(self, ele, prop):
+        # 1 响应元素
+        if isinstance(ele, etree._Element):
+            if prop != '':  # 获得属性
+                return ele.get(prop)
+            return ele.get_value_or_text()
+        # 2 页面元素
+        if prop != '':  # 获得属性
+            return ele.attribute(prop)
+        return ele.get_value_or_text()
\ No newline at end of file
